==> pf4-component-mapper-3.4.1.tgz: package/esm/wizard/wizard-components/wizard-toggle.js <==
import React from 'react';
import PropTypes from 'prop-types';
import AngleRightIcon from "@patternfly/react-icons/dist/esm/icons/angle-right-icon";
import CaretDownIcon from "@patternfly/react-icons/dist/esm/icons/caret-down-icon";

var WizardToggle = function WizardToggle(_ref) {
  var _navSchema$find, _navSchema$find2, _navSchema$find3;

  var activeStepIndex = _ref.activeStepIndex,
      currentStep = _ref.currentStep,
      navSchema = _ref.navSchema,
      isOpen = _ref.isOpen,
      dispatch = _ref.dispatch;
  var substepTitle = (_navSchema$find = navSchema.find(function (step) {
    return step.name === currentStep.name;
  })) === null || _navSchema$find === void 0 ? void 0 : _navSchema$find.substepOfTitle;
  var substepName = (_navSchema$find2 = navSchema.find(function (step) {
    return step.name === currentStep.name;
  })) === null || _navSchema$find2 === void 0 ? void 0 : _navSchema$find2.substepOf;
  var index = substepName ? (_navSchema$find3 = navSchema.find(function (step) {
    return step.substepOf === substepName;
  })) === null || _navSchema$find3 === void 0 ? void 0 : _navSchema$find3.index : activeStepIndex;
  var activeStepName = substepTitle || currentStep.title;
  var activeStepSubName = substepTitle ? currentStep.title : undefined;
  return /*#__PURE__*/React.createElement("button", {
    onClick: function onClick() {
      return dispatch({
        type: isOpen ? 'closeNav' : 'openNav'
      });
    },
    className: "pf-c-wizard__toggle ".concat(isOpen ? 'pf-m-expanded' : ''),
    "aria-label": "Wizard Toggle",
    "aria-expanded": isOpen,
    type: "button"
  }, /*#__PURE__*/React.createElement("ol", {
    className: "pf-c-wizard__toggle-list"
  }, /*#__PURE__*/React.createElement("li", {
    className: "pf-c-wizard__toggle-list-item"
  }, /*#__PURE__*/React.createElement("span", {
    className: "pf-c-wizard__toggle-num"
  }, index + 1), " ", activeStepName, activeStepSubName && /*#__PURE__*/React.createElement(AngleRightIcon, {
    className: "pf-c-wizard__toggle-separator",
    "aria-hidden": "true"
  })), activeStepSubName && /*#__PURE__*/React.createElement("li", {
    className: "pf-c-wizard__toggle-list-item"
  }, activeStepSubName)), /*#__PURE__*/React.createElement("span", {
    className: "pf-c-wizard__toggle-icon"
  }, /*#__PURE__*/React.createElement(CaretDownIcon, {
    "aria-hidden": "true"
  })));
};

WizardToggle.propTypes = {
  activeStepIndex: PropTypes.number,
  currentStep: PropTypes.object,
  navSchema: PropTypes.array,
  isOpen: PropTypes.bool,
  dispatch: PropTypes.func
};
export default WizardToggle;

==> pf4-component-mapper-3.23.0.tgz: package/esm/wizard/wizard-components/wizard-toggle.js <==
import React from 'react';
import PropTypes from 'prop-types';
import AngleRightIcon from "@patternfly/react-icons/dist/dynamic/icons/angle-right-icon";
import CaretDownIcon from "@patternfly/react-icons/dist/dynamic/icons/caret-down-icon";

var WizardToggle = function WizardToggle(_ref) {
  var _navSchema$find, _navSchema$find2, _navSchema$find3;

  var activeStepIndex = _ref.activeStepIndex,
      currentStep = _ref.currentStep,
      navSchema = _ref.navSchema,
      isOpen = _ref.isOpen,
      dispatch = _ref.dispatch;
  var substepTitle = (_navSchema$find = navSchema.find(function (step) {
    return step.name === currentStep.name;
  })) === null || _navSchema$find === void 0 ? void 0 : _navSchema$find.substepOfTitle;
  var substepName = (_navSchema$find2 = navSchema.find(function (step) {
    return step.name === currentStep.name;
  })) === null || _navSchema$find2 === void 0 ? void 0 : _navSchema$find2.substepOf;
  var index = substepName ? (_navSchema$find3 = navSchema.find(function (step) {
    return step.substepOf === substepName;
  })) === null || _navSchema$find3 === void 0 ? void 0 : _navSchema$find3.index : activeStepIndex;
  var activeStepName = substepTitle || currentStep.title;
  var activeStepSubName = substepTitle ? currentStep.title : undefined;
  return /*#__PURE__*/React.createElement("button", {
    onClick: function onClick() {
      return dispatch({
        type: isOpen ? 'closeNav' : 'openNav'
      });
    },
    className: "pf-v5-c-wizard__toggle ".concat(isOpen ? 'pf-m-expanded' : ''),
    "aria-label": "Wizard Toggle",
    "aria-expanded": isOpen,
    type: "button"
  }, /*#__PURE__*/React.createElement("ol", {
    className: "pf-v5-c-wizard__toggle-list"
  }, /*#__PURE__*/React.createElement("li", {
    className: "pf-v5-c-wizard__toggle-list-item"
  }, /*#__PURE__*/React.createElement("span", {
    className: "pf-v5-c-wizard__toggle-num"
  }, index + 1), " ", activeStepName, activeStepSubName && /*#__PURE__*/React.createElement(AngleRightIcon, {
    className: "pf-v5-c-wizard__toggle-separator",
    "aria-hidden": "true"
  })), activeStepSubName && /*#__PURE__*/React.createElement("li", {
    className: "pf-v5-c-wizard__toggle-list-item"
  }, activeStepSubName)), /*#__PURE__*/React.createElement("span", {
    className: "pf-v5-c-wizard__toggle-icon"
  }, /*#__PURE__*/React.createElement(CaretDownIcon, {
    "aria-hidden": "true"
  })));
};

WizardToggle.propTypes = {
  activeStepIndex: PropTypes.number,
  currentStep: PropTypes.object,
  navSchema: PropTypes.array,
  isOpen: PropTypes.bool,
  dispatch: PropTypes.func
};
export default WizardToggle;
